function [ambs, plt]=ravine_search_CMOD5(arg)
% 
% [ambs, plt]=ravine_search_CMOD5(arg)
%
% Use least-squares estimation to estimate the best speed at
% a given direction dir given measurements and their corresponding
% geometry where the i-th row of arg is given by arg(i,:)=[A,T,sigma-0]
% with 
%   A is the antenna azimuth angle relative to north in deg
%   T is the incidence angle in deg (26-66)
%   sigma-0 is the sigma-0 measurement (normal space)
%
% returns local mins in ambs and plotting variables in plt
%  ambs=[spd,dir,obj]   plt=[spd,dir,obj]
%
% note: code is for illustration purposes and is not intended to be efficient!
% written by D.G. Long at BYU Dec 2011
% 

% set up directional optimization which uses a global variable to pass geometry
global search_geom

options=optimset('TolX',0.1); % 0.1 m/s speed precision

% evaluate objective function for each direction of search
dirs1=0:2:359;  % consider directions only at 2 deg increments to save time
spds1=zeros(size(dirs1));
objs1=zeros(size(dirs1));
for idir=1:length(dirs1)
  % set global variable to pass function arguments
  search_geom=[dirs1(idir)+zeros(size(arg(:,1))),arg(:,1),arg(:,2),arg(:,3)];
  % call matlab optimization of speed at a particular direction
  [spds1(idir) objs1(idir)]=fminbnd(@dirmin,1,50,options);
end

% save results to output array for for plotting
plt=[spds1',dirs1',objs1'];

% find local minima using very simple search
objs1=[objs1(end) objs1(1:end) objs1(1)];
%
namb=0;
spds=[];
dirs=[];
objs=[];
for idir=1:length(dirs1)
  if objs1(idir+1)<=objs1(idir) && ...
	objs1(idir+1)<=objs1(idir+2) % local min found
    namb=namb+1;
    spds(namb)=spds1(idir);
    dirs(namb)=dirs1(idir);
    objs(namb)=objs1(idir);
  end
end

% return ambiguities in output array
ambs=[spds',dirs',objs'];
